@@ -5,5 +5,5 @@ base=`pwd`
 export PATH
 export PYTHONPATH
 PYTHONPATH=$base
-PATH=$base/scripts:$PATH
+PATH=$base/scripts:$base/scripts/pegasus:$base/scripts/utilities:$PATH
 
