@@ -3,7 +3,7 @@ Generic parser that uses a fixed event name and puts all the
 information in a single string-valued attribute.
 """
 __author__ = 'Dan Gunter dkgunter@lbl.gov'
-__rcsid__ = '$Id: generic.py 1030 2008-09-12 19:52:45Z dang $'
+__rcsid__ = '$Id: generic.py 24753 2010-04-29 04:14:31Z dang $'
 
 from logging import DEBUG
 import time
@@ -15,8 +15,9 @@ class Parser(BaseParser):
     information in a single string-valued attribute.
 
     Parameters:
-        - attribute_name {*'msg'*}: Output name for the attribute containing the input line.
-        - event_name {*'event'*}: Output event name
+        - attribute_name {STRING,'msg'*}: Output name for the attribute containing 
+                                          the input line.
+        - event_name {STRING,'event'*}: Output event name
     """
     def __init__(self, f, attribute_name='msg', event_name='event', **kwargs):
         BaseParser.__init__(self, f, fullname=__name__, **kwargs)
